TransactionAccess

Trait TransactionAccess 

pub trait TransactionAccess {
    // Required methods
    fn slot(&self) -> Result<u64, DecodeError>;
    fn index(&self) -> Result<Option<usize>, DecodeError>;
    fn signature(&self) -> Result<&Signature, DecodeError>;
    fn num_signers(&self, is_writable: bool) -> Result<usize, DecodeError>;
    fn num_accounts(&self) -> usize;
    fn message_signature(&self, idx: usize) -> Option<&Signature>;
    fn account_meta(
        &self,
        idx: usize,
    ) -> Result<Option<AccountMeta>, DecodeError>;
    fn num_address_table_lookups(&self) -> usize;
    fn address_table_lookup(
        &self,
        idx: usize,
    ) -> Option<&MessageAddressTableLookup>;
    fn num_instructions(&self) -> usize;
    fn instruction(&self, idx: usize) -> Option<&CompiledInstruction>;
    fn transaction_status_meta(&self) -> Option<&UiTransactionStatusMeta>;
}
Access a transaction.

Required Methods

fn slot(&self) -> Result<u64, DecodeError>

Gets the slot of the transaction where the events were generated.

fn index(&self) -> Result<Option<usize>, DecodeError>

Gets the index in the block of the transaction where the events were generated.

Note

The index may be None because for old transaction info format, the index of the transaction is not provided.

fn signature(&self) -> Result<&Signature, DecodeError>

Gets the signature of the transaction where the events were generated.

fn num_signers(&self, is_writable: bool) -> Result<usize, DecodeError>

Returns the number of signers.

fn num_accounts(&self) -> usize

Returns the number of accounts.

fn message_signature(&self, idx: usize) -> Option<&Signature>

Gets message signature.

fn account_meta(&self, idx: usize) -> Result<Option<AccountMeta>, DecodeError>

Gets account meta by index.

fn num_address_table_lookups(&self) -> usize

Returns the number of address table lookups.

fn address_table_lookup(&self, idx: usize) -> Option<&MessageAddressTableLookup>

Gets address table lookup by index.

fn num_instructions(&self) -> usize

Returns the number of instructions.

fn instruction(&self, idx: usize) -> Option<&CompiledInstruction>

Gets instruction by index.

fn transaction_status_meta(&self) -> Option<&UiTransactionStatusMeta>

Returns transaction status meta if available.

Implementors

Source

impl TransactionAccess for DecodedTransaction<'_>

Available on crate feature solana-decoder only.